Snowflex.Error exception (Snowflex v1.2.1)

Error module for Snowflex.

Summary

Types

t()

The error type for Snowflex.

Types

t()

@type t() :: %Snowflex.Error{
  __exception__: true,
  code: String.t(),
  message: String.t(),
  metadata: any(),
  sql_state: String.t()
}

The error type for Snowflex.

Fields

  • message: The error message.
  • code: The error code (from Snowflake).
  • sql_state: The SQL state (from Snowflake).
  • metadata: The metadata. Includes the request and response from the Snowflake API, as well as the options passed to the query.