Snowflex.Result (Snowflex v1.2.1)

Represents the result of a Snowflake query execution.

This struct contains all relevant information returned from a Snowflake query:

  • :columns - List of column names returned in the result set
  • :rows - List of tuples containing the row data
  • :num_rows - Number of rows in the result set
  • :metadata - Additional metadata about the query execution
  • :messages - Any messages returned by Snowflake during query execution
  • :query - The SQL statement that was executed
  • :query_id - The ID of the query that was executed
  • :request_id - The ID of the request that was executed
  • :sql_state - The SQL state of the query that was executed

Summary

Types

t()

@type t() :: %Snowflex.Result{
  columns: [String.t()] | nil,
  messages: [map()],
  metadata: [map()],
  num_rows: integer(),
  query: Snowflex.Query.t() | nil,
  query_id: String.t() | nil,
  request_id: String.t() | nil,
  rows: [tuple()] | nil,
  sql_state: String.t() | nil
}