Snowflex.Result (Snowflex v1.2.1)
View SourceRepresents the result of a Snowflake query execution.
This struct contains all relevant information returned from a Snowflake query:
:columns- List of column names returned in the result set:rows- List of tuples containing the row data:num_rows- Number of rows in the result set:metadata- Additional metadata about the query execution:messages- Any messages returned by Snowflake during query execution:query- The SQL statement that was executed:query_id- The ID of the query that was executed:request_id- The ID of the request that was executed:sql_state- The SQL state of the query that was executed